# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from onshape_client.oas.api_client import ApiClient
from onshape_client.oas.exceptions import (
    ApiTypeError,
    ApiValueError
)


class FeatureStudiosApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_feature_studio(self, did, wid, bt_model_element_params, **kwargs):  # noqa: E501
        """create_feature_studio  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_feature_studio(did, wid, bt_model_element_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str did: (required)
        :param str wid: (required)
        :param BTModelElementParams bt_model_element_params: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_feature_studio_with_http_info(did, wid, bt_model_element_params, **kwargs)  # noqa: E501

    def create_feature_studio_with_http_info(self, did, wid, bt_model_element_params, **kwargs):  # noqa: E501
        """create_feature_studio  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_feature_studio_with_http_info(did, wid, bt_model_element_params, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str did: (required)
        :param str wid: (required)
        :param BTModelElementParams bt_model_element_params: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wid', 'bt_model_element_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_feature_studio" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ApiValueError("Missing the required parameter `did` when calling `create_feature_studio`")  # noqa: E501
        # verify the required parameter 'wid' is set
        if ('wid' not in local_var_params or
                local_var_params['wid'] is None):
            raise ApiValueError("Missing the required parameter `wid` when calling `create_feature_studio`")  # noqa: E501
        # verify the required parameter 'bt_model_element_params' is set
        if ('bt_model_element_params' not in local_var_params or
                local_var_params['bt_model_element_params'] is None):
            raise ApiValueError("Missing the required parameter `bt_model_element_params` when calling `create_feature_studio`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wid' in local_var_params:
            path_params['wid'] = local_var_params['wid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'bt_model_element_params' in local_var_params:
            body_params = local_var_params['bt_model_element_params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8;qs=0.1', 'application/json;charset=UTF-8; qs=0.09'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8; qs=0.09'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/featurestudios/d/{did}/w/{wid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_feature_studio_contents(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """Get Feature Studio Contents.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_feature_studio_contents(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BTFeatureStudioContents
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_feature_studio_contents_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501

    def get_feature_studio_contents_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """Get Feature Studio Contents.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_feature_studio_contents_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BTFeatureStudioContents, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_feature_studio_contents" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ApiValueError("Missing the required parameter `did` when calling `get_feature_studio_contents`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ApiValueError("Missing the required parameter `wvm` when calling `get_feature_studio_contents`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ApiValueError("Missing the required parameter `wvmid` when calling `get_feature_studio_contents`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ApiValueError("Missing the required parameter `eid` when calling `get_feature_studio_contents`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8;qs=0.1', 'application/json;charset=UTF-8; qs=0.09'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/featurestudios/d/{did}/{wvm}/{wvmid}/e/{eid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BTFeatureStudioContents',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_feature_studio_specs(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_feature_studio_specs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_feature_studio_specs(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_feature_studio_specs_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501

    def get_feature_studio_specs_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_feature_studio_specs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_feature_studio_specs_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_feature_studio_specs" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ApiValueError("Missing the required parameter `did` when calling `get_feature_studio_specs`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ApiValueError("Missing the required parameter `wvm` when calling `get_feature_studio_specs`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ApiValueError("Missing the required parameter `wvmid` when calling `get_feature_studio_specs`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ApiValueError("Missing the required parameter `eid` when calling `get_feature_studio_specs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8;qs=0.1', 'application/json;charset=UTF-8; qs=0.09'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/featurestudios/d/{did}/{wvm}/{wvmid}/e/{eid}/featurespecs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_feature_studio_contents(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """update_feature_studio_contents  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_feature_studio_contents(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_feature_studio_contents_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501

    def update_feature_studio_contents_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """update_feature_studio_contents  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_feature_studio_contents_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_feature_studio_contents" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ApiValueError("Missing the required parameter `did` when calling `update_feature_studio_contents`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ApiValueError("Missing the required parameter `wvm` when calling `update_feature_studio_contents`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ApiValueError("Missing the required parameter `wvmid` when calling `update_feature_studio_contents`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ApiValueError("Missing the required parameter `eid` when calling `update_feature_studio_contents`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8;qs=0.1', 'application/json;charset=UTF-8; qs=0.09'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8; qs=0.09'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/featurestudios/d/{did}/{wvm}/{wvmid}/e/{eid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



from onshape_client.utility import get_field

def test_assembly_definition(client, configurable_cubes_assemblies):
    cube = configurable_cubes_assemblies[2]
    did = cube.did
    vid = cube.wvmid
    eid = cube.eid
    assert client.assemblies_api.get_assembly_definition1(did, 'v', vid, eid, _preload_content=False)
    # issue #4
    res = client.assemblies_api.get_assembly_definition1(did, 'v', vid, eid, include_mate_features=True, include_mate_connectors=True, _preload_content=False)
    parts = get_field(res, "parts")
    assert parts[0]["mateConnectors"]


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAPIApplicationExtensionParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'action_url': 'str',
        'action_type': 'int',
        'extension_type': 'int',
        'shows_response': 'bool',
        'description': 'str',
        'client_id': 'str',
        'name': 'str'
    }

    attribute_map = {
        'action_url': 'actionUrl',
        'action_type': 'actionType',
        'extension_type': 'extensionType',
        'shows_response': 'showsResponse',
        'description': 'description',
        'client_id': 'clientId',
        'name': 'name'
    }

    def __init__(self, action_url=None, action_type=None, extension_type=None, shows_response=None, description=None, client_id=None, name=None):  # noqa: E501
        """BTAPIApplicationExtensionParams - a model defined in OpenAPI"""  # noqa: E501

        self._action_url = None
        self._action_type = None
        self._extension_type = None
        self._shows_response = None
        self._description = None
        self._client_id = None
        self._name = None
        self.discriminator = None

        if action_url is not None:
            self.action_url = action_url
        if action_type is not None:
            self.action_type = action_type
        if extension_type is not None:
            self.extension_type = extension_type
        if shows_response is not None:
            self.shows_response = shows_response
        if description is not None:
            self.description = description
        if client_id is not None:
            self.client_id = client_id
        if name is not None:
            self.name = name

    @property
    def action_url(self):
        """Gets the action_url of this BTAPIApplicationExtensionParams.  # noqa: E501


        :return: The action_url of this BTAPIApplicationExtensionParams.  # noqa: E501
        :rtype: str
        """
        return self._action_url

    @action_url.setter
    def action_url(self, action_url):
        """Sets the action_url of this BTAPIApplicationExtensionParams.


        :param action_url: The action_url of this BTAPIApplicationExtensionParams.  # noqa: E501
        :type: str
        """

        self._action_url = action_url

    @property
    def action_type(self):
        """Gets the action_type of this BTAPIApplicationExtensionParams.  # noqa: E501


        :return: The action_type of this BTAPIApplicationExtensionParams.  # noqa: E501
        :rtype: int
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this BTAPIApplicationExtensionParams.


        :param action_type: The action_type of this BTAPIApplicationExtensionParams.  # noqa: E501
        :type: int
        """

        self._action_type = action_type

    @property
    def extension_type(self):
        """Gets the extension_type of this BTAPIApplicationExtensionParams.  # noqa: E501


        :return: The extension_type of this BTAPIApplicationExtensionParams.  # noqa: E501
        :rtype: int
        """
        return self._extension_type

    @extension_type.setter
    def extension_type(self, extension_type):
        """Sets the extension_type of this BTAPIApplicationExtensionParams.


        :param extension_type: The extension_type of this BTAPIApplicationExtensionParams.  # noqa: E501
        :type: int
        """

        self._extension_type = extension_type

    @property
    def shows_response(self):
        """Gets the shows_response of this BTAPIApplicationExtensionParams.  # noqa: E501


        :return: The shows_response of this BTAPIApplicationExtensionParams.  # noqa: E501
        :rtype: bool
        """
        return self._shows_response

    @shows_response.setter
    def shows_response(self, shows_response):
        """Sets the shows_response of this BTAPIApplicationExtensionParams.


        :param shows_response: The shows_response of this BTAPIApplicationExtensionParams.  # noqa: E501
        :type: bool
        """

        self._shows_response = shows_response

    @property
    def description(self):
        """Gets the description of this BTAPIApplicationExtensionParams.  # noqa: E501


        :return: The description of this BTAPIApplicationExtensionParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTAPIApplicationExtensionParams.


        :param description: The description of this BTAPIApplicationExtensionParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def client_id(self):
        """Gets the client_id of this BTAPIApplicationExtensionParams.  # noqa: E501


        :return: The client_id of this BTAPIApplicationExtensionParams.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this BTAPIApplicationExtensionParams.


        :param client_id: The client_id of this BTAPIApplicationExtensionParams.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def name(self):
        """Gets the name of this BTAPIApplicationExtensionParams.  # noqa: E501


        :return: The name of this BTAPIApplicationExtensionParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTAPIApplicationExtensionParams.


        :param name: The name of this BTAPIApplicationExtensionParams.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAPIApplicationExtensionParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTUserEmailVerifyParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'request_id': 'str',
        'user_id': 'str',
        'email': 'str',
        'secret': 'str'
    }

    attribute_map = {
        'request_id': 'requestId',
        'user_id': 'userId',
        'email': 'email',
        'secret': 'secret'
    }

    def __init__(self, request_id=None, user_id=None, email=None, secret=None):  # noqa: E501
        """BTUserEmailVerifyParams - a model defined in OpenAPI"""  # noqa: E501

        self._request_id = None
        self._user_id = None
        self._email = None
        self._secret = None
        self.discriminator = None

        if request_id is not None:
            self.request_id = request_id
        if user_id is not None:
            self.user_id = user_id
        if email is not None:
            self.email = email
        if secret is not None:
            self.secret = secret

    @property
    def request_id(self):
        """Gets the request_id of this BTUserEmailVerifyParams.  # noqa: E501


        :return: The request_id of this BTUserEmailVerifyParams.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this BTUserEmailVerifyParams.


        :param request_id: The request_id of this BTUserEmailVerifyParams.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def user_id(self):
        """Gets the user_id of this BTUserEmailVerifyParams.  # noqa: E501


        :return: The user_id of this BTUserEmailVerifyParams.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this BTUserEmailVerifyParams.


        :param user_id: The user_id of this BTUserEmailVerifyParams.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def email(self):
        """Gets the email of this BTUserEmailVerifyParams.  # noqa: E501


        :return: The email of this BTUserEmailVerifyParams.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this BTUserEmailVerifyParams.


        :param email: The email of this BTUserEmailVerifyParams.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def secret(self):
        """Gets the secret of this BTUserEmailVerifyParams.  # noqa: E501


        :return: The secret of this BTUserEmailVerifyParams.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this BTUserEmailVerifyParams.


        :param secret: The secret of this BTUserEmailVerifyParams.  # noqa: E501
        :type: str
        """

        self._secret = secret

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTUserEmailVerifyParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTIdentity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'identity_type': 'str',
        'identity_id': 'str'
    }

    attribute_map = {
        'identity_type': 'identityType',
        'identity_id': 'identityId'
    }

    def __init__(self, identity_type=None, identity_id=None):  # noqa: E501
        """BTIdentity - a model defined in OpenAPI"""  # noqa: E501

        self._identity_type = None
        self._identity_id = None
        self.discriminator = None

        if identity_type is not None:
            self.identity_type = identity_type
        if identity_id is not None:
            self.identity_id = identity_id

    @property
    def identity_type(self):
        """Gets the identity_type of this BTIdentity.  # noqa: E501


        :return: The identity_type of this BTIdentity.  # noqa: E501
        :rtype: str
        """
        return self._identity_type

    @identity_type.setter
    def identity_type(self, identity_type):
        """Sets the identity_type of this BTIdentity.


        :param identity_type: The identity_type of this BTIdentity.  # noqa: E501
        :type: str
        """
        allowed_values = ["USER", "TEAM"]  # noqa: E501
        if identity_type not in allowed_values:
            raise ValueError(
                "Invalid value for `identity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(identity_type, allowed_values)
            )

        self._identity_type = identity_type

    @property
    def identity_id(self):
        """Gets the identity_id of this BTIdentity.  # noqa: E501


        :return: The identity_id of this BTIdentity.  # noqa: E501
        :rtype: str
        """
        return self._identity_id

    @identity_id.setter
    def identity_id(self, identity_id):
        """Sets the identity_id of this BTIdentity.


        :param identity_id: The identity_id of this BTIdentity.  # noqa: E501
        :type: str
        """

        self._identity_id = identity_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTIdentity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDocumentSummarySearchInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'description': 'str',
        'tree_href': 'str',
        'is_mutable': 'bool',
        'resource_type': 'str',
        'project_id': 'str',
        'can_move': 'bool',
        'is_container': 'bool',
        'created_at': 'datetime',
        'is_enterprise_owned': 'bool',
        'modified_at': 'datetime',
        'created_by': 'BTUserBasicSummaryInfo',
        'modified_by': 'BTUserBasicSummaryInfo',
        'owner': 'BTOwnerInfo',
        'has_pending_owner': 'bool',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str',
        'name': 'str',
        'json_type': 'str',
        'parent_id': 'str',
        'permission_set': 'object',
        'trash': 'bool',
        'total_workspaces_updating': 'int',
        'total_workspaces_scheduled_for_update': 'int',
        'can_unshare': 'bool',
        'thumbnail': 'BTThumbnailInfo',
        'support_team_user_and_shared': 'bool',
        'liked_by_current_user': 'bool',
        'document_labels': 'list[BTDocumentLabelInfo]',
        'number_of_times_referenced': 'int',
        'number_of_times_copied': 'int',
        'likes': 'int',
        'recent_version': 'BTBaseInfo',
        'has_relevant_insertables': 'bool',
        'created_with_education_plan': 'bool',
        'not_revision_managed': 'bool',
        'anonymous_access_allowed': 'bool',
        'anonymous_allows_export': 'bool',
        'default_element_id': 'str',
        'default_workspace': 'BTBaseInfo',
        'trashed_at': 'datetime',
        'public': 'bool',
        'is_orphaned': 'bool',
        'tags': 'list[str]',
        'has_release_revisionable_objects': 'bool',
        'user_account_limits_breached': 'bool',
        'is_using_managed_workflow': 'bool',
        'permission': 'str',
        'search_hits': 'list[BTDocumentSearchHitInfo]'
    }

    attribute_map = {
        'description': 'description',
        'tree_href': 'treeHref',
        'is_mutable': 'isMutable',
        'resource_type': 'resourceType',
        'project_id': 'projectId',
        'can_move': 'canMove',
        'is_container': 'isContainer',
        'created_at': 'createdAt',
        'is_enterprise_owned': 'isEnterpriseOwned',
        'modified_at': 'modifiedAt',
        'created_by': 'createdBy',
        'modified_by': 'modifiedBy',
        'owner': 'owner',
        'has_pending_owner': 'hasPendingOwner',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef',
        'name': 'name',
        'json_type': 'jsonType',
        'parent_id': 'parentId',
        'permission_set': 'permissionSet',
        'trash': 'trash',
        'total_workspaces_updating': 'totalWorkspacesUpdating',
        'total_workspaces_scheduled_for_update': 'totalWorkspacesScheduledForUpdate',
        'can_unshare': 'canUnshare',
        'thumbnail': 'thumbnail',
        'support_team_user_and_shared': 'supportTeamUserAndShared',
        'liked_by_current_user': 'likedByCurrentUser',
        'document_labels': 'documentLabels',
        'number_of_times_referenced': 'numberOfTimesReferenced',
        'number_of_times_copied': 'numberOfTimesCopied',
        'likes': 'likes',
        'recent_version': 'recentVersion',
        'has_relevant_insertables': 'hasRelevantInsertables',
        'created_with_education_plan': 'createdWithEducationPlan',
        'not_revision_managed': 'notRevisionManaged',
        'anonymous_access_allowed': 'anonymousAccessAllowed',
        'anonymous_allows_export': 'anonymousAllowsExport',
        'default_element_id': 'defaultElementId',
        'default_workspace': 'defaultWorkspace',
        'trashed_at': 'trashedAt',
        'public': 'public',
        'is_orphaned': 'isOrphaned',
        'tags': 'tags',
        'has_release_revisionable_objects': 'hasReleaseRevisionableObjects',
        'user_account_limits_breached': 'userAccountLimitsBreached',
        'is_using_managed_workflow': 'isUsingManagedWorkflow',
        'permission': 'permission',
        'search_hits': 'searchHits'
    }

    def __init__(self, description=None, tree_href=None, is_mutable=None, resource_type=None, project_id=None, can_move=None, is_container=None, created_at=None, is_enterprise_owned=None, modified_at=None, created_by=None, modified_by=None, owner=None, has_pending_owner=None, id=None, href=None, view_ref=None, name=None, json_type=None, parent_id=None, permission_set=None, trash=None, total_workspaces_updating=None, total_workspaces_scheduled_for_update=None, can_unshare=None, thumbnail=None, support_team_user_and_shared=None, liked_by_current_user=None, document_labels=None, number_of_times_referenced=None, number_of_times_copied=None, likes=None, recent_version=None, has_relevant_insertables=None, created_with_education_plan=None, not_revision_managed=None, anonymous_access_allowed=None, anonymous_allows_export=None, default_element_id=None, default_workspace=None, trashed_at=None, public=None, is_orphaned=None, tags=None, has_release_revisionable_objects=None, user_account_limits_breached=None, is_using_managed_workflow=None, permission=None, search_hits=None):  # noqa: E501
        """BTDocumentSummarySearchInfo - a model defined in OpenAPI"""  # noqa: E501

        self._description = None
        self._tree_href = None
        self._is_mutable = None
        self._resource_type = None
        self._project_id = None
        self._can_move = None
        self._is_container = None
        self._created_at = None
        self._is_enterprise_owned = None
        self._modified_at = None
        self._created_by = None
        self._modified_by = None
        self._owner = None
        self._has_pending_owner = None
        self._id = None
        self._href = None
        self._view_ref = None
        self._name = None
        self._json_type = None
        self._parent_id = None
        self._permission_set = None
        self._trash = None
        self._total_workspaces_updating = None
        self._total_workspaces_scheduled_for_update = None
        self._can_unshare = None
        self._thumbnail = None
        self._support_team_user_and_shared = None
        self._liked_by_current_user = None
        self._document_labels = None
        self._number_of_times_referenced = None
        self._number_of_times_copied = None
        self._likes = None
        self._recent_version = None
        self._has_relevant_insertables = None
        self._created_with_education_plan = None
        self._not_revision_managed = None
        self._anonymous_access_allowed = None
        self._anonymous_allows_export = None
        self._default_element_id = None
        self._default_workspace = None
        self._trashed_at = None
        self._public = None
        self._is_orphaned = None
        self._tags = None
        self._has_release_revisionable_objects = None
        self._user_account_limits_breached = None
        self._is_using_managed_workflow = None
        self._permission = None
        self._search_hits = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if tree_href is not None:
            self.tree_href = tree_href
        if is_mutable is not None:
            self.is_mutable = is_mutable
        if resource_type is not None:
            self.resource_type = resource_type
        if project_id is not None:
            self.project_id = project_id
        if can_move is not None:
            self.can_move = can_move
        if is_container is not None:
            self.is_container = is_container
        if created_at is not None:
            self.created_at = created_at
        if is_enterprise_owned is not None:
            self.is_enterprise_owned = is_enterprise_owned
        if modified_at is not None:
            self.modified_at = modified_at
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by
        if owner is not None:
            self.owner = owner
        if has_pending_owner is not None:
            self.has_pending_owner = has_pending_owner
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref
        if name is not None:
            self.name = name
        self.json_type = json_type
        if parent_id is not None:
            self.parent_id = parent_id
        if permission_set is not None:
            self.permission_set = permission_set
        if trash is not None:
            self.trash = trash
        if total_workspaces_updating is not None:
            self.total_workspaces_updating = total_workspaces_updating
        if total_workspaces_scheduled_for_update is not None:
            self.total_workspaces_scheduled_for_update = total_workspaces_scheduled_for_update
        if can_unshare is not None:
            self.can_unshare = can_unshare
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if support_team_user_and_shared is not None:
            self.support_team_user_and_shared = support_team_user_and_shared
        if liked_by_current_user is not None:
            self.liked_by_current_user = liked_by_current_user
        if document_labels is not None:
            self.document_labels = document_labels
        if number_of_times_referenced is not None:
            self.number_of_times_referenced = number_of_times_referenced
        if number_of_times_copied is not None:
            self.number_of_times_copied = number_of_times_copied
        if likes is not None:
            self.likes = likes
        if recent_version is not None:
            self.recent_version = recent_version
        if has_relevant_insertables is not None:
            self.has_relevant_insertables = has_relevant_insertables
        if created_with_education_plan is not None:
            self.created_with_education_plan = created_with_education_plan
        if not_revision_managed is not None:
            self.not_revision_managed = not_revision_managed
        if anonymous_access_allowed is not None:
            self.anonymous_access_allowed = anonymous_access_allowed
        if anonymous_allows_export is not None:
            self.anonymous_allows_export = anonymous_allows_export
        if default_element_id is not None:
            self.default_element_id = default_element_id
        if default_workspace is not None:
            self.default_workspace = default_workspace
        if trashed_at is not None:
            self.trashed_at = trashed_at
        if public is not None:
            self.public = public
        if is_orphaned is not None:
            self.is_orphaned = is_orphaned
        if tags is not None:
            self.tags = tags
        if has_release_revisionable_objects is not None:
            self.has_release_revisionable_objects = has_release_revisionable_objects
        if user_account_limits_breached is not None:
            self.user_account_limits_breached = user_account_limits_breached
        if is_using_managed_workflow is not None:
            self.is_using_managed_workflow = is_using_managed_workflow
        if permission is not None:
            self.permission = permission
        if search_hits is not None:
            self.search_hits = search_hits

    @property
    def description(self):
        """Gets the description of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The description of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTDocumentSummarySearchInfo.


        :param description: The description of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def tree_href(self):
        """Gets the tree_href of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The tree_href of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: str
        """
        return self._tree_href

    @tree_href.setter
    def tree_href(self, tree_href):
        """Sets the tree_href of this BTDocumentSummarySearchInfo.


        :param tree_href: The tree_href of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: str
        """

        self._tree_href = tree_href

    @property
    def is_mutable(self):
        """Gets the is_mutable of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The is_mutable of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_mutable

    @is_mutable.setter
    def is_mutable(self, is_mutable):
        """Sets the is_mutable of this BTDocumentSummarySearchInfo.


        :param is_mutable: The is_mutable of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._is_mutable = is_mutable

    @property
    def resource_type(self):
        """Gets the resource_type of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The resource_type of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this BTDocumentSummarySearchInfo.


        :param resource_type: The resource_type of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def project_id(self):
        """Gets the project_id of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The project_id of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this BTDocumentSummarySearchInfo.


        :param project_id: The project_id of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def can_move(self):
        """Gets the can_move of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The can_move of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_move

    @can_move.setter
    def can_move(self, can_move):
        """Sets the can_move of this BTDocumentSummarySearchInfo.


        :param can_move: The can_move of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._can_move = can_move

    @property
    def is_container(self):
        """Gets the is_container of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The is_container of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_container

    @is_container.setter
    def is_container(self, is_container):
        """Sets the is_container of this BTDocumentSummarySearchInfo.


        :param is_container: The is_container of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._is_container = is_container

    @property
    def created_at(self):
        """Gets the created_at of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The created_at of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BTDocumentSummarySearchInfo.


        :param created_at: The created_at of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def is_enterprise_owned(self):
        """Gets the is_enterprise_owned of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The is_enterprise_owned of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_enterprise_owned

    @is_enterprise_owned.setter
    def is_enterprise_owned(self, is_enterprise_owned):
        """Sets the is_enterprise_owned of this BTDocumentSummarySearchInfo.


        :param is_enterprise_owned: The is_enterprise_owned of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._is_enterprise_owned = is_enterprise_owned

    @property
    def modified_at(self):
        """Gets the modified_at of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The modified_at of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this BTDocumentSummarySearchInfo.


        :param modified_at: The modified_at of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    @property
    def created_by(self):
        """Gets the created_by of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The created_by of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: BTUserBasicSummaryInfo
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this BTDocumentSummarySearchInfo.


        :param created_by: The created_by of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: BTUserBasicSummaryInfo
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The modified_by of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: BTUserBasicSummaryInfo
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this BTDocumentSummarySearchInfo.


        :param modified_by: The modified_by of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: BTUserBasicSummaryInfo
        """

        self._modified_by = modified_by

    @property
    def owner(self):
        """Gets the owner of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The owner of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: BTOwnerInfo
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this BTDocumentSummarySearchInfo.


        :param owner: The owner of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: BTOwnerInfo
        """

        self._owner = owner

    @property
    def has_pending_owner(self):
        """Gets the has_pending_owner of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The has_pending_owner of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_pending_owner

    @has_pending_owner.setter
    def has_pending_owner(self, has_pending_owner):
        """Sets the has_pending_owner of this BTDocumentSummarySearchInfo.


        :param has_pending_owner: The has_pending_owner of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._has_pending_owner = has_pending_owner

    @property
    def id(self):
        """Gets the id of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The id of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTDocumentSummarySearchInfo.


        :param id: The id of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The href of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTDocumentSummarySearchInfo.


        :param href: The href of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The view_ref of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTDocumentSummarySearchInfo.


        :param view_ref: The view_ref of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    @property
    def name(self):
        """Gets the name of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The name of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTDocumentSummarySearchInfo.


        :param name: The name of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def json_type(self):
        """Gets the json_type of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The json_type of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: str
        """
        return self._json_type

    @json_type.setter
    def json_type(self, json_type):
        """Sets the json_type of this BTDocumentSummarySearchInfo.


        :param json_type: The json_type of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: str
        """
        if json_type is None:
            raise ValueError("Invalid value for `json_type`, must not be `None`")  # noqa: E501

        self._json_type = json_type

    @property
    def parent_id(self):
        """Gets the parent_id of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The parent_id of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this BTDocumentSummarySearchInfo.


        :param parent_id: The parent_id of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def permission_set(self):
        """Gets the permission_set of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The permission_set of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: object
        """
        return self._permission_set

    @permission_set.setter
    def permission_set(self, permission_set):
        """Sets the permission_set of this BTDocumentSummarySearchInfo.


        :param permission_set: The permission_set of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: object
        """

        self._permission_set = permission_set

    @property
    def trash(self):
        """Gets the trash of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The trash of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._trash

    @trash.setter
    def trash(self, trash):
        """Sets the trash of this BTDocumentSummarySearchInfo.


        :param trash: The trash of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._trash = trash

    @property
    def total_workspaces_updating(self):
        """Gets the total_workspaces_updating of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The total_workspaces_updating of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: int
        """
        return self._total_workspaces_updating

    @total_workspaces_updating.setter
    def total_workspaces_updating(self, total_workspaces_updating):
        """Sets the total_workspaces_updating of this BTDocumentSummarySearchInfo.


        :param total_workspaces_updating: The total_workspaces_updating of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: int
        """

        self._total_workspaces_updating = total_workspaces_updating

    @property
    def total_workspaces_scheduled_for_update(self):
        """Gets the total_workspaces_scheduled_for_update of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The total_workspaces_scheduled_for_update of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: int
        """
        return self._total_workspaces_scheduled_for_update

    @total_workspaces_scheduled_for_update.setter
    def total_workspaces_scheduled_for_update(self, total_workspaces_scheduled_for_update):
        """Sets the total_workspaces_scheduled_for_update of this BTDocumentSummarySearchInfo.


        :param total_workspaces_scheduled_for_update: The total_workspaces_scheduled_for_update of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: int
        """

        self._total_workspaces_scheduled_for_update = total_workspaces_scheduled_for_update

    @property
    def can_unshare(self):
        """Gets the can_unshare of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The can_unshare of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_unshare

    @can_unshare.setter
    def can_unshare(self, can_unshare):
        """Sets the can_unshare of this BTDocumentSummarySearchInfo.


        :param can_unshare: The can_unshare of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._can_unshare = can_unshare

    @property
    def thumbnail(self):
        """Gets the thumbnail of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The thumbnail of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: BTThumbnailInfo
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail):
        """Sets the thumbnail of this BTDocumentSummarySearchInfo.


        :param thumbnail: The thumbnail of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: BTThumbnailInfo
        """

        self._thumbnail = thumbnail

    @property
    def support_team_user_and_shared(self):
        """Gets the support_team_user_and_shared of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The support_team_user_and_shared of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._support_team_user_and_shared

    @support_team_user_and_shared.setter
    def support_team_user_and_shared(self, support_team_user_and_shared):
        """Sets the support_team_user_and_shared of this BTDocumentSummarySearchInfo.


        :param support_team_user_and_shared: The support_team_user_and_shared of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._support_team_user_and_shared = support_team_user_and_shared

    @property
    def liked_by_current_user(self):
        """Gets the liked_by_current_user of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The liked_by_current_user of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._liked_by_current_user

    @liked_by_current_user.setter
    def liked_by_current_user(self, liked_by_current_user):
        """Sets the liked_by_current_user of this BTDocumentSummarySearchInfo.


        :param liked_by_current_user: The liked_by_current_user of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._liked_by_current_user = liked_by_current_user

    @property
    def document_labels(self):
        """Gets the document_labels of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The document_labels of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: list[BTDocumentLabelInfo]
        """
        return self._document_labels

    @document_labels.setter
    def document_labels(self, document_labels):
        """Sets the document_labels of this BTDocumentSummarySearchInfo.


        :param document_labels: The document_labels of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: list[BTDocumentLabelInfo]
        """

        self._document_labels = document_labels

    @property
    def number_of_times_referenced(self):
        """Gets the number_of_times_referenced of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The number_of_times_referenced of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: int
        """
        return self._number_of_times_referenced

    @number_of_times_referenced.setter
    def number_of_times_referenced(self, number_of_times_referenced):
        """Sets the number_of_times_referenced of this BTDocumentSummarySearchInfo.


        :param number_of_times_referenced: The number_of_times_referenced of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: int
        """

        self._number_of_times_referenced = number_of_times_referenced

    @property
    def number_of_times_copied(self):
        """Gets the number_of_times_copied of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The number_of_times_copied of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: int
        """
        return self._number_of_times_copied

    @number_of_times_copied.setter
    def number_of_times_copied(self, number_of_times_copied):
        """Sets the number_of_times_copied of this BTDocumentSummarySearchInfo.


        :param number_of_times_copied: The number_of_times_copied of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: int
        """

        self._number_of_times_copied = number_of_times_copied

    @property
    def likes(self):
        """Gets the likes of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The likes of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: int
        """
        return self._likes

    @likes.setter
    def likes(self, likes):
        """Sets the likes of this BTDocumentSummarySearchInfo.


        :param likes: The likes of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: int
        """

        self._likes = likes

    @property
    def recent_version(self):
        """Gets the recent_version of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The recent_version of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: BTBaseInfo
        """
        return self._recent_version

    @recent_version.setter
    def recent_version(self, recent_version):
        """Sets the recent_version of this BTDocumentSummarySearchInfo.


        :param recent_version: The recent_version of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: BTBaseInfo
        """

        self._recent_version = recent_version

    @property
    def has_relevant_insertables(self):
        """Gets the has_relevant_insertables of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The has_relevant_insertables of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_relevant_insertables

    @has_relevant_insertables.setter
    def has_relevant_insertables(self, has_relevant_insertables):
        """Sets the has_relevant_insertables of this BTDocumentSummarySearchInfo.


        :param has_relevant_insertables: The has_relevant_insertables of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._has_relevant_insertables = has_relevant_insertables

    @property
    def created_with_education_plan(self):
        """Gets the created_with_education_plan of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The created_with_education_plan of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._created_with_education_plan

    @created_with_education_plan.setter
    def created_with_education_plan(self, created_with_education_plan):
        """Sets the created_with_education_plan of this BTDocumentSummarySearchInfo.


        :param created_with_education_plan: The created_with_education_plan of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._created_with_education_plan = created_with_education_plan

    @property
    def not_revision_managed(self):
        """Gets the not_revision_managed of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The not_revision_managed of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._not_revision_managed

    @not_revision_managed.setter
    def not_revision_managed(self, not_revision_managed):
        """Sets the not_revision_managed of this BTDocumentSummarySearchInfo.


        :param not_revision_managed: The not_revision_managed of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._not_revision_managed = not_revision_managed

    @property
    def anonymous_access_allowed(self):
        """Gets the anonymous_access_allowed of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The anonymous_access_allowed of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._anonymous_access_allowed

    @anonymous_access_allowed.setter
    def anonymous_access_allowed(self, anonymous_access_allowed):
        """Sets the anonymous_access_allowed of this BTDocumentSummarySearchInfo.


        :param anonymous_access_allowed: The anonymous_access_allowed of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._anonymous_access_allowed = anonymous_access_allowed

    @property
    def anonymous_allows_export(self):
        """Gets the anonymous_allows_export of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The anonymous_allows_export of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._anonymous_allows_export

    @anonymous_allows_export.setter
    def anonymous_allows_export(self, anonymous_allows_export):
        """Sets the anonymous_allows_export of this BTDocumentSummarySearchInfo.


        :param anonymous_allows_export: The anonymous_allows_export of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._anonymous_allows_export = anonymous_allows_export

    @property
    def default_element_id(self):
        """Gets the default_element_id of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The default_element_id of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: str
        """
        return self._default_element_id

    @default_element_id.setter
    def default_element_id(self, default_element_id):
        """Sets the default_element_id of this BTDocumentSummarySearchInfo.


        :param default_element_id: The default_element_id of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: str
        """

        self._default_element_id = default_element_id

    @property
    def default_workspace(self):
        """Gets the default_workspace of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The default_workspace of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: BTBaseInfo
        """
        return self._default_workspace

    @default_workspace.setter
    def default_workspace(self, default_workspace):
        """Sets the default_workspace of this BTDocumentSummarySearchInfo.


        :param default_workspace: The default_workspace of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: BTBaseInfo
        """

        self._default_workspace = default_workspace

    @property
    def trashed_at(self):
        """Gets the trashed_at of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The trashed_at of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._trashed_at

    @trashed_at.setter
    def trashed_at(self, trashed_at):
        """Sets the trashed_at of this BTDocumentSummarySearchInfo.


        :param trashed_at: The trashed_at of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: datetime
        """

        self._trashed_at = trashed_at

    @property
    def public(self):
        """Gets the public of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The public of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this BTDocumentSummarySearchInfo.


        :param public: The public of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._public = public

    @property
    def is_orphaned(self):
        """Gets the is_orphaned of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The is_orphaned of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_orphaned

    @is_orphaned.setter
    def is_orphaned(self, is_orphaned):
        """Sets the is_orphaned of this BTDocumentSummarySearchInfo.


        :param is_orphaned: The is_orphaned of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._is_orphaned = is_orphaned

    @property
    def tags(self):
        """Gets the tags of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The tags of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this BTDocumentSummarySearchInfo.


        :param tags: The tags of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def has_release_revisionable_objects(self):
        """Gets the has_release_revisionable_objects of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The has_release_revisionable_objects of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_release_revisionable_objects

    @has_release_revisionable_objects.setter
    def has_release_revisionable_objects(self, has_release_revisionable_objects):
        """Sets the has_release_revisionable_objects of this BTDocumentSummarySearchInfo.


        :param has_release_revisionable_objects: The has_release_revisionable_objects of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._has_release_revisionable_objects = has_release_revisionable_objects

    @property
    def user_account_limits_breached(self):
        """Gets the user_account_limits_breached of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The user_account_limits_breached of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._user_account_limits_breached

    @user_account_limits_breached.setter
    def user_account_limits_breached(self, user_account_limits_breached):
        """Sets the user_account_limits_breached of this BTDocumentSummarySearchInfo.


        :param user_account_limits_breached: The user_account_limits_breached of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._user_account_limits_breached = user_account_limits_breached

    @property
    def is_using_managed_workflow(self):
        """Gets the is_using_managed_workflow of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The is_using_managed_workflow of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_using_managed_workflow

    @is_using_managed_workflow.setter
    def is_using_managed_workflow(self, is_using_managed_workflow):
        """Sets the is_using_managed_workflow of this BTDocumentSummarySearchInfo.


        :param is_using_managed_workflow: The is_using_managed_workflow of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: bool
        """

        self._is_using_managed_workflow = is_using_managed_workflow

    @property
    def permission(self):
        """Gets the permission of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The permission of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: str
        """
        return self._permission

    @permission.setter
    def permission(self, permission):
        """Sets the permission of this BTDocumentSummarySearchInfo.


        :param permission: The permission of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["NOACCESS", "ANONYMOUS_ACCESS", "READ", "READ_COPY_EXPORT", "COMMENT", "WRITE", "RESHARE", "FULL", "OWNER"]  # noqa: E501
        if permission not in allowed_values:
            raise ValueError(
                "Invalid value for `permission` ({0}), must be one of {1}"  # noqa: E501
                .format(permission, allowed_values)
            )

        self._permission = permission

    @property
    def search_hits(self):
        """Gets the search_hits of this BTDocumentSummarySearchInfo.  # noqa: E501


        :return: The search_hits of this BTDocumentSummarySearchInfo.  # noqa: E501
        :rtype: list[BTDocumentSearchHitInfo]
        """
        return self._search_hits

    @search_hits.setter
    def search_hits(self, search_hits):
        """Sets the search_hits of this BTDocumentSummarySearchInfo.


        :param search_hits: The search_hits of this BTDocumentSummarySearchInfo.  # noqa: E501
        :type: list[BTDocumentSearchHitInfo]
        """

        self._search_hits = search_hits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDocumentSummarySearchInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAclEntryInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'entry_id': 'str',
        'entry_type': 'int',
        'permission_set': 'object',
        'image': 'str',
        'entry_state': 'str',
        'enterprise_member': 'bool',
        'pending_owner_transfer': 'bool',
        'accept_owner_transfer': 'bool',
        'object_id': 'str',
        'team_name': 'str',
        'email': 'str',
        'company_name': 'str',
        'name': 'str',
        'permission': 'int'
    }

    attribute_map = {
        'entry_id': 'entryId',
        'entry_type': 'entryType',
        'permission_set': 'permissionSet',
        'image': 'image',
        'entry_state': 'entryState',
        'enterprise_member': 'enterpriseMember',
        'pending_owner_transfer': 'pendingOwnerTransfer',
        'accept_owner_transfer': 'acceptOwnerTransfer',
        'object_id': 'objectId',
        'team_name': 'teamName',
        'email': 'email',
        'company_name': 'companyName',
        'name': 'name',
        'permission': 'permission'
    }

    def __init__(self, entry_id=None, entry_type=None, permission_set=None, image=None, entry_state=None, enterprise_member=None, pending_owner_transfer=None, accept_owner_transfer=None, object_id=None, team_name=None, email=None, company_name=None, name=None, permission=None):  # noqa: E501
        """BTAclEntryInfo - a model defined in OpenAPI"""  # noqa: E501

        self._entry_id = None
        self._entry_type = None
        self._permission_set = None
        self._image = None
        self._entry_state = None
        self._enterprise_member = None
        self._pending_owner_transfer = None
        self._accept_owner_transfer = None
        self._object_id = None
        self._team_name = None
        self._email = None
        self._company_name = None
        self._name = None
        self._permission = None
        self.discriminator = None

        if entry_id is not None:
            self.entry_id = entry_id
        if entry_type is not None:
            self.entry_type = entry_type
        if permission_set is not None:
            self.permission_set = permission_set
        if image is not None:
            self.image = image
        if entry_state is not None:
            self.entry_state = entry_state
        if enterprise_member is not None:
            self.enterprise_member = enterprise_member
        if pending_owner_transfer is not None:
            self.pending_owner_transfer = pending_owner_transfer
        if accept_owner_transfer is not None:
            self.accept_owner_transfer = accept_owner_transfer
        if object_id is not None:
            self.object_id = object_id
        if team_name is not None:
            self.team_name = team_name
        if email is not None:
            self.email = email
        if company_name is not None:
            self.company_name = company_name
        if name is not None:
            self.name = name
        if permission is not None:
            self.permission = permission

    @property
    def entry_id(self):
        """Gets the entry_id of this BTAclEntryInfo.  # noqa: E501


        :return: The entry_id of this BTAclEntryInfo.  # noqa: E501
        :rtype: str
        """
        return self._entry_id

    @entry_id.setter
    def entry_id(self, entry_id):
        """Sets the entry_id of this BTAclEntryInfo.


        :param entry_id: The entry_id of this BTAclEntryInfo.  # noqa: E501
        :type: str
        """

        self._entry_id = entry_id

    @property
    def entry_type(self):
        """Gets the entry_type of this BTAclEntryInfo.  # noqa: E501


        :return: The entry_type of this BTAclEntryInfo.  # noqa: E501
        :rtype: int
        """
        return self._entry_type

    @entry_type.setter
    def entry_type(self, entry_type):
        """Sets the entry_type of this BTAclEntryInfo.


        :param entry_type: The entry_type of this BTAclEntryInfo.  # noqa: E501
        :type: int
        """

        self._entry_type = entry_type

    @property
    def permission_set(self):
        """Gets the permission_set of this BTAclEntryInfo.  # noqa: E501


        :return: The permission_set of this BTAclEntryInfo.  # noqa: E501
        :rtype: object
        """
        return self._permission_set

    @permission_set.setter
    def permission_set(self, permission_set):
        """Sets the permission_set of this BTAclEntryInfo.


        :param permission_set: The permission_set of this BTAclEntryInfo.  # noqa: E501
        :type: object
        """

        self._permission_set = permission_set

    @property
    def image(self):
        """Gets the image of this BTAclEntryInfo.  # noqa: E501


        :return: The image of this BTAclEntryInfo.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this BTAclEntryInfo.


        :param image: The image of this BTAclEntryInfo.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def entry_state(self):
        """Gets the entry_state of this BTAclEntryInfo.  # noqa: E501


        :return: The entry_state of this BTAclEntryInfo.  # noqa: E501
        :rtype: str
        """
        return self._entry_state

    @entry_state.setter
    def entry_state(self, entry_state):
        """Sets the entry_state of this BTAclEntryInfo.


        :param entry_state: The entry_state of this BTAclEntryInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["DELETED", "ACTIVE", "INACTIVE", "REQUESTED", "APPROVED", "REQUEST_EXPIRED", "ALL", "MARKED_FOR_DELETION"]  # noqa: E501
        if entry_state not in allowed_values:
            raise ValueError(
                "Invalid value for `entry_state` ({0}), must be one of {1}"  # noqa: E501
                .format(entry_state, allowed_values)
            )

        self._entry_state = entry_state

    @property
    def enterprise_member(self):
        """Gets the enterprise_member of this BTAclEntryInfo.  # noqa: E501


        :return: The enterprise_member of this BTAclEntryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._enterprise_member

    @enterprise_member.setter
    def enterprise_member(self, enterprise_member):
        """Sets the enterprise_member of this BTAclEntryInfo.


        :param enterprise_member: The enterprise_member of this BTAclEntryInfo.  # noqa: E501
        :type: bool
        """

        self._enterprise_member = enterprise_member

    @property
    def pending_owner_transfer(self):
        """Gets the pending_owner_transfer of this BTAclEntryInfo.  # noqa: E501


        :return: The pending_owner_transfer of this BTAclEntryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._pending_owner_transfer

    @pending_owner_transfer.setter
    def pending_owner_transfer(self, pending_owner_transfer):
        """Sets the pending_owner_transfer of this BTAclEntryInfo.


        :param pending_owner_transfer: The pending_owner_transfer of this BTAclEntryInfo.  # noqa: E501
        :type: bool
        """

        self._pending_owner_transfer = pending_owner_transfer

    @property
    def accept_owner_transfer(self):
        """Gets the accept_owner_transfer of this BTAclEntryInfo.  # noqa: E501


        :return: The accept_owner_transfer of this BTAclEntryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._accept_owner_transfer

    @accept_owner_transfer.setter
    def accept_owner_transfer(self, accept_owner_transfer):
        """Sets the accept_owner_transfer of this BTAclEntryInfo.


        :param accept_owner_transfer: The accept_owner_transfer of this BTAclEntryInfo.  # noqa: E501
        :type: bool
        """

        self._accept_owner_transfer = accept_owner_transfer

    @property
    def object_id(self):
        """Gets the object_id of this BTAclEntryInfo.  # noqa: E501


        :return: The object_id of this BTAclEntryInfo.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this BTAclEntryInfo.


        :param object_id: The object_id of this BTAclEntryInfo.  # noqa: E501
        :type: str
        """

        self._object_id = object_id

    @property
    def team_name(self):
        """Gets the team_name of this BTAclEntryInfo.  # noqa: E501


        :return: The team_name of this BTAclEntryInfo.  # noqa: E501
        :rtype: str
        """
        return self._team_name

    @team_name.setter
    def team_name(self, team_name):
        """Sets the team_name of this BTAclEntryInfo.


        :param team_name: The team_name of this BTAclEntryInfo.  # noqa: E501
        :type: str
        """

        self._team_name = team_name

    @property
    def email(self):
        """Gets the email of this BTAclEntryInfo.  # noqa: E501


        :return: The email of this BTAclEntryInfo.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this BTAclEntryInfo.


        :param email: The email of this BTAclEntryInfo.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def company_name(self):
        """Gets the company_name of this BTAclEntryInfo.  # noqa: E501


        :return: The company_name of this BTAclEntryInfo.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this BTAclEntryInfo.


        :param company_name: The company_name of this BTAclEntryInfo.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def name(self):
        """Gets the name of this BTAclEntryInfo.  # noqa: E501


        :return: The name of this BTAclEntryInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTAclEntryInfo.


        :param name: The name of this BTAclEntryInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def permission(self):
        """Gets the permission of this BTAclEntryInfo.  # noqa: E501


        :return: The permission of this BTAclEntryInfo.  # noqa: E501
        :rtype: int
        """
        return self._permission

    @permission.setter
    def permission(self, permission):
        """Sets the permission of this BTAclEntryInfo.


        :param permission: The permission of this BTAclEntryInfo.  # noqa: E501
        :type: int
        """

        self._permission = permission

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAclEntryInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""For getting measurements defined by the custom "measure" feature: https://cad.onshape.com/documents/78aa66ffe6f1daceb9cfad3d/v/025bec5f59f6380ab5627a4b/e/92549789b92e9aa35f676f4e

To fetch measurements from the API:

1. Make sure the desired geometry is defined using the feature within this document. The "use measurements variable" checkbox should be selected.
2. Call the Evaluate Featurescript API call with your client/code with the following script:

	function(context, queries) {
            return getAllVariables(context, "m");
        }

This will return all the variables defined under "m", ie, m.radius, m.my_custom_length, etc...
3. Now use the resulting map from measurements feature name to value within your code.
"""

from onshape_client.client import Client
from onshape_client.onshape_url import OnshapeElement
from onshape_client.models.bt_feature_script_eval_call import BTFeatureScriptEvalCall
from onshape_client.utility import parse_quantity
import json

script = \
    r"""
    function(context, queries) {
            return getAllVariables(context);
        }
    """


def main():
    element = OnshapeElement(
        "https://cad.onshape.com/documents/78aa66ffe6f1daceb9cfad3d/v/e36c0bd857c2a2a8b2107a40/e/92549789b92e9aa35f676f4e")
    script_call = BTFeatureScriptEvalCall(script=script)
    client = Client.get_client()
    response = client.part_studios_api.eval_feature_script(element.did,
                                                           element.wvm,
                                                           element.wvmid,
                                                           element.eid,
                                                           bt_feature_script_eval_call=script_call,
                                                           _preload_content=False)
    measurements = json.loads(response.data.decode("utf-8"))["result"]["message"]["value"]
    parsed_measurements = parse_variables_from_map(measurements)

    print("Measurements: \n" + str(parsed_measurements))


def parse_variables_from_map(unparsed):
    parsed_variables = {}
    value = None
    for to_parse in unparsed:
        if is_fs_type(to_parse, 'BTFSValueMapEntry'):
            key = to_parse["message"]["key"]["message"]["value"]
            candidate_message = to_parse['message']['value']
            if is_fs_type(candidate_message, ['BTFSValueMap', 'BTFSValueArray']):
                value = parse_variables_from_map(candidate_message["message"]["value"])
            elif is_fs_type(candidate_message, 'BTFSValueWithUnits'):
                value = parse_quantity(candidate_message["message"])
            parsed_variables[key] = value
    return parsed_variables


def is_fs_type(candidate, type_name):
    result = False
    try:
        if isinstance(type_name, str):
            result = type_name == candidate['typeName']
        elif isinstance(type_name, list):
            result = any([type_name_one == candidate['typeName'] for type_name_one in type_name])
    except Exception:
        result = False
    return result


if __name__ == '__main__':
    main()

"""
Measurements: 
{'distance_from_polygon_to_square': '0.1308455707096832*meter', 'diameter': '0.0868175271040671*meter', 'polygon_side_length': '0.05706864859958895*meter'}
"""


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDocumentSearchHitInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'document_id': 'str',
        'highlighted_fields': 'dict(str, list[str])',
        'type': 'str',
        'name': 'str',
        'source_map': 'dict(str, object)',
        'element_name': 'str',
        'hit': 'BTESDocumentHit',
        'version_or_workspace_name': 'str'
    }

    attribute_map = {
        'document_id': 'documentId',
        'highlighted_fields': 'highlightedFields',
        'type': 'type',
        'name': 'name',
        'source_map': 'sourceMap',
        'element_name': 'elementName',
        'hit': 'hit',
        'version_or_workspace_name': 'versionOrWorkspaceName'
    }

    def __init__(self, document_id=None, highlighted_fields=None, type=None, name=None, source_map=None, element_name=None, hit=None, version_or_workspace_name=None):  # noqa: E501
        """BTDocumentSearchHitInfo - a model defined in OpenAPI"""  # noqa: E501

        self._document_id = None
        self._highlighted_fields = None
        self._type = None
        self._name = None
        self._source_map = None
        self._element_name = None
        self._hit = None
        self._version_or_workspace_name = None
        self.discriminator = None

        if document_id is not None:
            self.document_id = document_id
        if highlighted_fields is not None:
            self.highlighted_fields = highlighted_fields
        if type is not None:
            self.type = type
        if name is not None:
            self.name = name
        if source_map is not None:
            self.source_map = source_map
        if element_name is not None:
            self.element_name = element_name
        if hit is not None:
            self.hit = hit
        if version_or_workspace_name is not None:
            self.version_or_workspace_name = version_or_workspace_name

    @property
    def document_id(self):
        """Gets the document_id of this BTDocumentSearchHitInfo.  # noqa: E501


        :return: The document_id of this BTDocumentSearchHitInfo.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTDocumentSearchHitInfo.


        :param document_id: The document_id of this BTDocumentSearchHitInfo.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def highlighted_fields(self):
        """Gets the highlighted_fields of this BTDocumentSearchHitInfo.  # noqa: E501


        :return: The highlighted_fields of this BTDocumentSearchHitInfo.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._highlighted_fields

    @highlighted_fields.setter
    def highlighted_fields(self, highlighted_fields):
        """Sets the highlighted_fields of this BTDocumentSearchHitInfo.


        :param highlighted_fields: The highlighted_fields of this BTDocumentSearchHitInfo.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._highlighted_fields = highlighted_fields

    @property
    def type(self):
        """Gets the type of this BTDocumentSearchHitInfo.  # noqa: E501


        :return: The type of this BTDocumentSearchHitInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTDocumentSearchHitInfo.


        :param type: The type of this BTDocumentSearchHitInfo.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def name(self):
        """Gets the name of this BTDocumentSearchHitInfo.  # noqa: E501


        :return: The name of this BTDocumentSearchHitInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTDocumentSearchHitInfo.


        :param name: The name of this BTDocumentSearchHitInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def source_map(self):
        """Gets the source_map of this BTDocumentSearchHitInfo.  # noqa: E501


        :return: The source_map of this BTDocumentSearchHitInfo.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._source_map

    @source_map.setter
    def source_map(self, source_map):
        """Sets the source_map of this BTDocumentSearchHitInfo.


        :param source_map: The source_map of this BTDocumentSearchHitInfo.  # noqa: E501
        :type: dict(str, object)
        """

        self._source_map = source_map

    @property
    def element_name(self):
        """Gets the element_name of this BTDocumentSearchHitInfo.  # noqa: E501


        :return: The element_name of this BTDocumentSearchHitInfo.  # noqa: E501
        :rtype: str
        """
        return self._element_name

    @element_name.setter
    def element_name(self, element_name):
        """Sets the element_name of this BTDocumentSearchHitInfo.


        :param element_name: The element_name of this BTDocumentSearchHitInfo.  # noqa: E501
        :type: str
        """

        self._element_name = element_name

    @property
    def hit(self):
        """Gets the hit of this BTDocumentSearchHitInfo.  # noqa: E501


        :return: The hit of this BTDocumentSearchHitInfo.  # noqa: E501
        :rtype: BTESDocumentHit
        """
        return self._hit

    @hit.setter
    def hit(self, hit):
        """Sets the hit of this BTDocumentSearchHitInfo.


        :param hit: The hit of this BTDocumentSearchHitInfo.  # noqa: E501
        :type: BTESDocumentHit
        """

        self._hit = hit

    @property
    def version_or_workspace_name(self):
        """Gets the version_or_workspace_name of this BTDocumentSearchHitInfo.  # noqa: E501


        :return: The version_or_workspace_name of this BTDocumentSearchHitInfo.  # noqa: E501
        :rtype: str
        """
        return self._version_or_workspace_name

    @version_or_workspace_name.setter
    def version_or_workspace_name(self, version_or_workspace_name):
        """Sets the version_or_workspace_name of this BTDocumentSearchHitInfo.


        :param version_or_workspace_name: The version_or_workspace_name of this BTDocumentSearchHitInfo.  # noqa: E501
        :type: str
        """

        self._version_or_workspace_name = version_or_workspace_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDocumentSearchHitInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTCloudStorageAccountInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cloud_storage_account_id_': 'str',
        'cloud_storage_account_id': 'str',
        'import_folder': 'BTCloudStorageObjectInfo',
        'export_folder': 'BTCloudStorageObjectInfo',
        'cloud_storage_provider': 'int',
        'enabled': 'bool'
    }

    attribute_map = {
        'cloud_storage_account_id_': 'cloudStorageAccountId_',
        'cloud_storage_account_id': 'cloudStorageAccountId',
        'import_folder': 'importFolder',
        'export_folder': 'exportFolder',
        'cloud_storage_provider': 'cloudStorageProvider',
        'enabled': 'enabled'
    }

    def __init__(self, cloud_storage_account_id_=None, cloud_storage_account_id=None, import_folder=None, export_folder=None, cloud_storage_provider=None, enabled=None):  # noqa: E501
        """BTCloudStorageAccountInfo - a model defined in OpenAPI"""  # noqa: E501

        self._cloud_storage_account_id_ = None
        self._cloud_storage_account_id = None
        self._import_folder = None
        self._export_folder = None
        self._cloud_storage_provider = None
        self._enabled = None
        self.discriminator = None

        if cloud_storage_account_id_ is not None:
            self.cloud_storage_account_id_ = cloud_storage_account_id_
        if cloud_storage_account_id is not None:
            self.cloud_storage_account_id = cloud_storage_account_id
        if import_folder is not None:
            self.import_folder = import_folder
        if export_folder is not None:
            self.export_folder = export_folder
        if cloud_storage_provider is not None:
            self.cloud_storage_provider = cloud_storage_provider
        if enabled is not None:
            self.enabled = enabled

    @property
    def cloud_storage_account_id_(self):
        """Gets the cloud_storage_account_id_ of this BTCloudStorageAccountInfo.  # noqa: E501


        :return: The cloud_storage_account_id_ of this BTCloudStorageAccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._cloud_storage_account_id_

    @cloud_storage_account_id_.setter
    def cloud_storage_account_id_(self, cloud_storage_account_id_):
        """Sets the cloud_storage_account_id_ of this BTCloudStorageAccountInfo.


        :param cloud_storage_account_id_: The cloud_storage_account_id_ of this BTCloudStorageAccountInfo.  # noqa: E501
        :type: str
        """

        self._cloud_storage_account_id_ = cloud_storage_account_id_

    @property
    def cloud_storage_account_id(self):
        """Gets the cloud_storage_account_id of this BTCloudStorageAccountInfo.  # noqa: E501


        :return: The cloud_storage_account_id of this BTCloudStorageAccountInfo.  # noqa: E501
        :rtype: str
        """
        return self._cloud_storage_account_id

    @cloud_storage_account_id.setter
    def cloud_storage_account_id(self, cloud_storage_account_id):
        """Sets the cloud_storage_account_id of this BTCloudStorageAccountInfo.


        :param cloud_storage_account_id: The cloud_storage_account_id of this BTCloudStorageAccountInfo.  # noqa: E501
        :type: str
        """

        self._cloud_storage_account_id = cloud_storage_account_id

    @property
    def import_folder(self):
        """Gets the import_folder of this BTCloudStorageAccountInfo.  # noqa: E501


        :return: The import_folder of this BTCloudStorageAccountInfo.  # noqa: E501
        :rtype: BTCloudStorageObjectInfo
        """
        return self._import_folder

    @import_folder.setter
    def import_folder(self, import_folder):
        """Sets the import_folder of this BTCloudStorageAccountInfo.


        :param import_folder: The import_folder of this BTCloudStorageAccountInfo.  # noqa: E501
        :type: BTCloudStorageObjectInfo
        """

        self._import_folder = import_folder

    @property
    def export_folder(self):
        """Gets the export_folder of this BTCloudStorageAccountInfo.  # noqa: E501


        :return: The export_folder of this BTCloudStorageAccountInfo.  # noqa: E501
        :rtype: BTCloudStorageObjectInfo
        """
        return self._export_folder

    @export_folder.setter
    def export_folder(self, export_folder):
        """Sets the export_folder of this BTCloudStorageAccountInfo.


        :param export_folder: The export_folder of this BTCloudStorageAccountInfo.  # noqa: E501
        :type: BTCloudStorageObjectInfo
        """

        self._export_folder = export_folder

    @property
    def cloud_storage_provider(self):
        """Gets the cloud_storage_provider of this BTCloudStorageAccountInfo.  # noqa: E501


        :return: The cloud_storage_provider of this BTCloudStorageAccountInfo.  # noqa: E501
        :rtype: int
        """
        return self._cloud_storage_provider

    @cloud_storage_provider.setter
    def cloud_storage_provider(self, cloud_storage_provider):
        """Sets the cloud_storage_provider of this BTCloudStorageAccountInfo.


        :param cloud_storage_provider: The cloud_storage_provider of this BTCloudStorageAccountInfo.  # noqa: E501
        :type: int
        """

        self._cloud_storage_provider = cloud_storage_provider

    @property
    def enabled(self):
        """Gets the enabled of this BTCloudStorageAccountInfo.  # noqa: E501


        :return: The enabled of this BTCloudStorageAccountInfo.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this BTCloudStorageAccountInfo.


        :param enabled: The enabled of this BTCloudStorageAccountInfo.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTCloudStorageAccountInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDocumentSummaryInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'parent_id': 'str',
        'permission_set': 'object',
        'trash': 'bool',
        'total_workspaces_updating': 'int',
        'total_workspaces_scheduled_for_update': 'int',
        'can_unshare': 'bool',
        'thumbnail': 'BTThumbnailInfo',
        'support_team_user_and_shared': 'bool',
        'liked_by_current_user': 'bool',
        'document_labels': 'list[BTDocumentLabelInfo]',
        'number_of_times_referenced': 'int',
        'number_of_times_copied': 'int',
        'likes': 'int',
        'recent_version': 'BTBaseInfo',
        'has_relevant_insertables': 'bool',
        'created_with_education_plan': 'bool',
        'not_revision_managed': 'bool',
        'anonymous_access_allowed': 'bool',
        'anonymous_allows_export': 'bool',
        'default_element_id': 'str',
        'default_workspace': 'BTBaseInfo',
        'trashed_at': 'datetime',
        'public': 'bool',
        'is_orphaned': 'bool',
        'tags': 'list[str]',
        'has_release_revisionable_objects': 'bool',
        'user_account_limits_breached': 'bool',
        'is_using_managed_workflow': 'bool',
        'permission': 'str'
    }

    attribute_map = {
        'parent_id': 'parentId',
        'permission_set': 'permissionSet',
        'trash': 'trash',
        'total_workspaces_updating': 'totalWorkspacesUpdating',
        'total_workspaces_scheduled_for_update': 'totalWorkspacesScheduledForUpdate',
        'can_unshare': 'canUnshare',
        'thumbnail': 'thumbnail',
        'support_team_user_and_shared': 'supportTeamUserAndShared',
        'liked_by_current_user': 'likedByCurrentUser',
        'document_labels': 'documentLabels',
        'number_of_times_referenced': 'numberOfTimesReferenced',
        'number_of_times_copied': 'numberOfTimesCopied',
        'likes': 'likes',
        'recent_version': 'recentVersion',
        'has_relevant_insertables': 'hasRelevantInsertables',
        'created_with_education_plan': 'createdWithEducationPlan',
        'not_revision_managed': 'notRevisionManaged',
        'anonymous_access_allowed': 'anonymousAccessAllowed',
        'anonymous_allows_export': 'anonymousAllowsExport',
        'default_element_id': 'defaultElementId',
        'default_workspace': 'defaultWorkspace',
        'trashed_at': 'trashedAt',
        'public': 'public',
        'is_orphaned': 'isOrphaned',
        'tags': 'tags',
        'has_release_revisionable_objects': 'hasReleaseRevisionableObjects',
        'user_account_limits_breached': 'userAccountLimitsBreached',
        'is_using_managed_workflow': 'isUsingManagedWorkflow',
        'permission': 'permission'
    }

    def __init__(self, parent_id=None, permission_set=None, trash=None, total_workspaces_updating=None, total_workspaces_scheduled_for_update=None, can_unshare=None, thumbnail=None, support_team_user_and_shared=None, liked_by_current_user=None, document_labels=None, number_of_times_referenced=None, number_of_times_copied=None, likes=None, recent_version=None, has_relevant_insertables=None, created_with_education_plan=None, not_revision_managed=None, anonymous_access_allowed=None, anonymous_allows_export=None, default_element_id=None, default_workspace=None, trashed_at=None, public=None, is_orphaned=None, tags=None, has_release_revisionable_objects=None, user_account_limits_breached=None, is_using_managed_workflow=None, permission=None):  # noqa: E501
        """BTDocumentSummaryInfo - a model defined in OpenAPI"""  # noqa: E501

        self._parent_id = None
        self._permission_set = None
        self._trash = None
        self._total_workspaces_updating = None
        self._total_workspaces_scheduled_for_update = None
        self._can_unshare = None
        self._thumbnail = None
        self._support_team_user_and_shared = None
        self._liked_by_current_user = None
        self._document_labels = None
        self._number_of_times_referenced = None
        self._number_of_times_copied = None
        self._likes = None
        self._recent_version = None
        self._has_relevant_insertables = None
        self._created_with_education_plan = None
        self._not_revision_managed = None
        self._anonymous_access_allowed = None
        self._anonymous_allows_export = None
        self._default_element_id = None
        self._default_workspace = None
        self._trashed_at = None
        self._public = None
        self._is_orphaned = None
        self._tags = None
        self._has_release_revisionable_objects = None
        self._user_account_limits_breached = None
        self._is_using_managed_workflow = None
        self._permission = None
        self.discriminator = None

        if parent_id is not None:
            self.parent_id = parent_id
        if permission_set is not None:
            self.permission_set = permission_set
        if trash is not None:
            self.trash = trash
        if total_workspaces_updating is not None:
            self.total_workspaces_updating = total_workspaces_updating
        if total_workspaces_scheduled_for_update is not None:
            self.total_workspaces_scheduled_for_update = total_workspaces_scheduled_for_update
        if can_unshare is not None:
            self.can_unshare = can_unshare
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if support_team_user_and_shared is not None:
            self.support_team_user_and_shared = support_team_user_and_shared
        if liked_by_current_user is not None:
            self.liked_by_current_user = liked_by_current_user
        if document_labels is not None:
            self.document_labels = document_labels
        if number_of_times_referenced is not None:
            self.number_of_times_referenced = number_of_times_referenced
        if number_of_times_copied is not None:
            self.number_of_times_copied = number_of_times_copied
        if likes is not None:
            self.likes = likes
        if recent_version is not None:
            self.recent_version = recent_version
        if has_relevant_insertables is not None:
            self.has_relevant_insertables = has_relevant_insertables
        if created_with_education_plan is not None:
            self.created_with_education_plan = created_with_education_plan
        if not_revision_managed is not None:
            self.not_revision_managed = not_revision_managed
        if anonymous_access_allowed is not None:
            self.anonymous_access_allowed = anonymous_access_allowed
        if anonymous_allows_export is not None:
            self.anonymous_allows_export = anonymous_allows_export
        if default_element_id is not None:
            self.default_element_id = default_element_id
        if default_workspace is not None:
            self.default_workspace = default_workspace
        if trashed_at is not None:
            self.trashed_at = trashed_at
        if public is not None:
            self.public = public
        if is_orphaned is not None:
            self.is_orphaned = is_orphaned
        if tags is not None:
            self.tags = tags
        if has_release_revisionable_objects is not None:
            self.has_release_revisionable_objects = has_release_revisionable_objects
        if user_account_limits_breached is not None:
            self.user_account_limits_breached = user_account_limits_breached
        if is_using_managed_workflow is not None:
            self.is_using_managed_workflow = is_using_managed_workflow
        if permission is not None:
            self.permission = permission

    @property
    def parent_id(self):
        """Gets the parent_id of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The parent_id of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this BTDocumentSummaryInfo.


        :param parent_id: The parent_id of this BTDocumentSummaryInfo.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def permission_set(self):
        """Gets the permission_set of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The permission_set of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: object
        """
        return self._permission_set

    @permission_set.setter
    def permission_set(self, permission_set):
        """Sets the permission_set of this BTDocumentSummaryInfo.


        :param permission_set: The permission_set of this BTDocumentSummaryInfo.  # noqa: E501
        :type: object
        """

        self._permission_set = permission_set

    @property
    def trash(self):
        """Gets the trash of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The trash of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._trash

    @trash.setter
    def trash(self, trash):
        """Sets the trash of this BTDocumentSummaryInfo.


        :param trash: The trash of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._trash = trash

    @property
    def total_workspaces_updating(self):
        """Gets the total_workspaces_updating of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The total_workspaces_updating of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: int
        """
        return self._total_workspaces_updating

    @total_workspaces_updating.setter
    def total_workspaces_updating(self, total_workspaces_updating):
        """Sets the total_workspaces_updating of this BTDocumentSummaryInfo.


        :param total_workspaces_updating: The total_workspaces_updating of this BTDocumentSummaryInfo.  # noqa: E501
        :type: int
        """

        self._total_workspaces_updating = total_workspaces_updating

    @property
    def total_workspaces_scheduled_for_update(self):
        """Gets the total_workspaces_scheduled_for_update of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The total_workspaces_scheduled_for_update of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: int
        """
        return self._total_workspaces_scheduled_for_update

    @total_workspaces_scheduled_for_update.setter
    def total_workspaces_scheduled_for_update(self, total_workspaces_scheduled_for_update):
        """Sets the total_workspaces_scheduled_for_update of this BTDocumentSummaryInfo.


        :param total_workspaces_scheduled_for_update: The total_workspaces_scheduled_for_update of this BTDocumentSummaryInfo.  # noqa: E501
        :type: int
        """

        self._total_workspaces_scheduled_for_update = total_workspaces_scheduled_for_update

    @property
    def can_unshare(self):
        """Gets the can_unshare of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The can_unshare of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_unshare

    @can_unshare.setter
    def can_unshare(self, can_unshare):
        """Sets the can_unshare of this BTDocumentSummaryInfo.


        :param can_unshare: The can_unshare of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._can_unshare = can_unshare

    @property
    def thumbnail(self):
        """Gets the thumbnail of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The thumbnail of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: BTThumbnailInfo
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail):
        """Sets the thumbnail of this BTDocumentSummaryInfo.


        :param thumbnail: The thumbnail of this BTDocumentSummaryInfo.  # noqa: E501
        :type: BTThumbnailInfo
        """

        self._thumbnail = thumbnail

    @property
    def support_team_user_and_shared(self):
        """Gets the support_team_user_and_shared of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The support_team_user_and_shared of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._support_team_user_and_shared

    @support_team_user_and_shared.setter
    def support_team_user_and_shared(self, support_team_user_and_shared):
        """Sets the support_team_user_and_shared of this BTDocumentSummaryInfo.


        :param support_team_user_and_shared: The support_team_user_and_shared of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._support_team_user_and_shared = support_team_user_and_shared

    @property
    def liked_by_current_user(self):
        """Gets the liked_by_current_user of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The liked_by_current_user of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._liked_by_current_user

    @liked_by_current_user.setter
    def liked_by_current_user(self, liked_by_current_user):
        """Sets the liked_by_current_user of this BTDocumentSummaryInfo.


        :param liked_by_current_user: The liked_by_current_user of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._liked_by_current_user = liked_by_current_user

    @property
    def document_labels(self):
        """Gets the document_labels of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The document_labels of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: list[BTDocumentLabelInfo]
        """
        return self._document_labels

    @document_labels.setter
    def document_labels(self, document_labels):
        """Sets the document_labels of this BTDocumentSummaryInfo.


        :param document_labels: The document_labels of this BTDocumentSummaryInfo.  # noqa: E501
        :type: list[BTDocumentLabelInfo]
        """

        self._document_labels = document_labels

    @property
    def number_of_times_referenced(self):
        """Gets the number_of_times_referenced of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The number_of_times_referenced of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: int
        """
        return self._number_of_times_referenced

    @number_of_times_referenced.setter
    def number_of_times_referenced(self, number_of_times_referenced):
        """Sets the number_of_times_referenced of this BTDocumentSummaryInfo.


        :param number_of_times_referenced: The number_of_times_referenced of this BTDocumentSummaryInfo.  # noqa: E501
        :type: int
        """

        self._number_of_times_referenced = number_of_times_referenced

    @property
    def number_of_times_copied(self):
        """Gets the number_of_times_copied of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The number_of_times_copied of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: int
        """
        return self._number_of_times_copied

    @number_of_times_copied.setter
    def number_of_times_copied(self, number_of_times_copied):
        """Sets the number_of_times_copied of this BTDocumentSummaryInfo.


        :param number_of_times_copied: The number_of_times_copied of this BTDocumentSummaryInfo.  # noqa: E501
        :type: int
        """

        self._number_of_times_copied = number_of_times_copied

    @property
    def likes(self):
        """Gets the likes of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The likes of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: int
        """
        return self._likes

    @likes.setter
    def likes(self, likes):
        """Sets the likes of this BTDocumentSummaryInfo.


        :param likes: The likes of this BTDocumentSummaryInfo.  # noqa: E501
        :type: int
        """

        self._likes = likes

    @property
    def recent_version(self):
        """Gets the recent_version of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The recent_version of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: BTBaseInfo
        """
        return self._recent_version

    @recent_version.setter
    def recent_version(self, recent_version):
        """Sets the recent_version of this BTDocumentSummaryInfo.


        :param recent_version: The recent_version of this BTDocumentSummaryInfo.  # noqa: E501
        :type: BTBaseInfo
        """

        self._recent_version = recent_version

    @property
    def has_relevant_insertables(self):
        """Gets the has_relevant_insertables of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The has_relevant_insertables of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_relevant_insertables

    @has_relevant_insertables.setter
    def has_relevant_insertables(self, has_relevant_insertables):
        """Sets the has_relevant_insertables of this BTDocumentSummaryInfo.


        :param has_relevant_insertables: The has_relevant_insertables of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._has_relevant_insertables = has_relevant_insertables

    @property
    def created_with_education_plan(self):
        """Gets the created_with_education_plan of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The created_with_education_plan of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._created_with_education_plan

    @created_with_education_plan.setter
    def created_with_education_plan(self, created_with_education_plan):
        """Sets the created_with_education_plan of this BTDocumentSummaryInfo.


        :param created_with_education_plan: The created_with_education_plan of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._created_with_education_plan = created_with_education_plan

    @property
    def not_revision_managed(self):
        """Gets the not_revision_managed of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The not_revision_managed of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._not_revision_managed

    @not_revision_managed.setter
    def not_revision_managed(self, not_revision_managed):
        """Sets the not_revision_managed of this BTDocumentSummaryInfo.


        :param not_revision_managed: The not_revision_managed of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._not_revision_managed = not_revision_managed

    @property
    def anonymous_access_allowed(self):
        """Gets the anonymous_access_allowed of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The anonymous_access_allowed of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._anonymous_access_allowed

    @anonymous_access_allowed.setter
    def anonymous_access_allowed(self, anonymous_access_allowed):
        """Sets the anonymous_access_allowed of this BTDocumentSummaryInfo.


        :param anonymous_access_allowed: The anonymous_access_allowed of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._anonymous_access_allowed = anonymous_access_allowed

    @property
    def anonymous_allows_export(self):
        """Gets the anonymous_allows_export of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The anonymous_allows_export of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._anonymous_allows_export

    @anonymous_allows_export.setter
    def anonymous_allows_export(self, anonymous_allows_export):
        """Sets the anonymous_allows_export of this BTDocumentSummaryInfo.


        :param anonymous_allows_export: The anonymous_allows_export of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._anonymous_allows_export = anonymous_allows_export

    @property
    def default_element_id(self):
        """Gets the default_element_id of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The default_element_id of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: str
        """
        return self._default_element_id

    @default_element_id.setter
    def default_element_id(self, default_element_id):
        """Sets the default_element_id of this BTDocumentSummaryInfo.


        :param default_element_id: The default_element_id of this BTDocumentSummaryInfo.  # noqa: E501
        :type: str
        """

        self._default_element_id = default_element_id

    @property
    def default_workspace(self):
        """Gets the default_workspace of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The default_workspace of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: BTBaseInfo
        """
        return self._default_workspace

    @default_workspace.setter
    def default_workspace(self, default_workspace):
        """Sets the default_workspace of this BTDocumentSummaryInfo.


        :param default_workspace: The default_workspace of this BTDocumentSummaryInfo.  # noqa: E501
        :type: BTBaseInfo
        """

        self._default_workspace = default_workspace

    @property
    def trashed_at(self):
        """Gets the trashed_at of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The trashed_at of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._trashed_at

    @trashed_at.setter
    def trashed_at(self, trashed_at):
        """Sets the trashed_at of this BTDocumentSummaryInfo.


        :param trashed_at: The trashed_at of this BTDocumentSummaryInfo.  # noqa: E501
        :type: datetime
        """

        self._trashed_at = trashed_at

    @property
    def public(self):
        """Gets the public of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The public of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this BTDocumentSummaryInfo.


        :param public: The public of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._public = public

    @property
    def is_orphaned(self):
        """Gets the is_orphaned of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The is_orphaned of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_orphaned

    @is_orphaned.setter
    def is_orphaned(self, is_orphaned):
        """Sets the is_orphaned of this BTDocumentSummaryInfo.


        :param is_orphaned: The is_orphaned of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._is_orphaned = is_orphaned

    @property
    def tags(self):
        """Gets the tags of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The tags of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this BTDocumentSummaryInfo.


        :param tags: The tags of this BTDocumentSummaryInfo.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def has_release_revisionable_objects(self):
        """Gets the has_release_revisionable_objects of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The has_release_revisionable_objects of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_release_revisionable_objects

    @has_release_revisionable_objects.setter
    def has_release_revisionable_objects(self, has_release_revisionable_objects):
        """Sets the has_release_revisionable_objects of this BTDocumentSummaryInfo.


        :param has_release_revisionable_objects: The has_release_revisionable_objects of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._has_release_revisionable_objects = has_release_revisionable_objects

    @property
    def user_account_limits_breached(self):
        """Gets the user_account_limits_breached of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The user_account_limits_breached of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._user_account_limits_breached

    @user_account_limits_breached.setter
    def user_account_limits_breached(self, user_account_limits_breached):
        """Sets the user_account_limits_breached of this BTDocumentSummaryInfo.


        :param user_account_limits_breached: The user_account_limits_breached of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._user_account_limits_breached = user_account_limits_breached

    @property
    def is_using_managed_workflow(self):
        """Gets the is_using_managed_workflow of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The is_using_managed_workflow of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_using_managed_workflow

    @is_using_managed_workflow.setter
    def is_using_managed_workflow(self, is_using_managed_workflow):
        """Sets the is_using_managed_workflow of this BTDocumentSummaryInfo.


        :param is_using_managed_workflow: The is_using_managed_workflow of this BTDocumentSummaryInfo.  # noqa: E501
        :type: bool
        """

        self._is_using_managed_workflow = is_using_managed_workflow

    @property
    def permission(self):
        """Gets the permission of this BTDocumentSummaryInfo.  # noqa: E501


        :return: The permission of this BTDocumentSummaryInfo.  # noqa: E501
        :rtype: str
        """
        return self._permission

    @permission.setter
    def permission(self, permission):
        """Sets the permission of this BTDocumentSummaryInfo.


        :param permission: The permission of this BTDocumentSummaryInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["NOACCESS", "ANONYMOUS_ACCESS", "READ", "READ_COPY_EXPORT", "COMMENT", "WRITE", "RESHARE", "FULL", "OWNER"]  # noqa: E501
        if permission not in allowed_values:
            raise ValueError(
                "Invalid value for `permission` ({0}), must be one of {1}"  # noqa: E501
                .format(permission, allowed_values)
            )

        self._permission = permission

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDocumentSummaryInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



'''
Export an STL
==============

Demos 307 redirects with the Onshape API
'''

from onshape_client.client import Client
from onshape_client.onshape_url import OnshapeElement, ConfiguredOnshapeElement
from onshape_client.units import u
from onshape_client.example_programs.onshape_models import cube

client = Client.get_client()

# get the STL export
stl = client.part_studios_api.export_stl1(cube.did, cube.wvm, cube.wvmid, cube.eid, _preload_content=False)

print("Resulting STL data (unconfigured): \n" + stl.data.decode("UTF-8"))

cube.update_current_configuration({'size': 40 * u.inch, 'edge_configuration': 'chamfered'})

# get the STL export
stl = client.part_studios_api.export_stl1(cube.did, cube.wvm, cube.wvmid, cube.eid, configuration=cube.get_configuration_string(), _preload_content=False)

print("Resulting STL data (configured): \n" + stl.data.decode("UTF-8"))


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.103
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTUpdateInContextParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'microversion_id': 'BTMicroversionId',
        'encoded_context_configuration': 'str',
        'use_latest_microversion': 'bool',
        'context_id': 'str',
        'description': 'str'
    }

    attribute_map = {
        'microversion_id': 'microversionId',
        'encoded_context_configuration': 'encodedContextConfiguration',
        'use_latest_microversion': 'useLatestMicroversion',
        'context_id': 'contextId',
        'description': 'description'
    }

    def __init__(self, microversion_id=None, encoded_context_configuration=None, use_latest_microversion=None, context_id=None, description=None):  # noqa: E501
        """BTUpdateInContextParams - a model defined in OpenAPI"""  # noqa: E501

        self._microversion_id = None
        self._encoded_context_configuration = None
        self._use_latest_microversion = None
        self._context_id = None
        self._description = None
        self.discriminator = None

        if microversion_id is not None:
            self.microversion_id = microversion_id
        if encoded_context_configuration is not None:
            self.encoded_context_configuration = encoded_context_configuration
        if use_latest_microversion is not None:
            self.use_latest_microversion = use_latest_microversion
        if context_id is not None:
            self.context_id = context_id
        if description is not None:
            self.description = description

    @property
    def microversion_id(self):
        """Gets the microversion_id of this BTUpdateInContextParams.  # noqa: E501


        :return: The microversion_id of this BTUpdateInContextParams.  # noqa: E501
        :rtype: BTMicroversionId
        """
        return self._microversion_id

    @microversion_id.setter
    def microversion_id(self, microversion_id):
        """Sets the microversion_id of this BTUpdateInContextParams.


        :param microversion_id: The microversion_id of this BTUpdateInContextParams.  # noqa: E501
        :type: BTMicroversionId
        """

        self._microversion_id = microversion_id

    @property
    def encoded_context_configuration(self):
        """Gets the encoded_context_configuration of this BTUpdateInContextParams.  # noqa: E501


        :return: The encoded_context_configuration of this BTUpdateInContextParams.  # noqa: E501
        :rtype: str
        """
        return self._encoded_context_configuration

    @encoded_context_configuration.setter
    def encoded_context_configuration(self, encoded_context_configuration):
        """Sets the encoded_context_configuration of this BTUpdateInContextParams.


        :param encoded_context_configuration: The encoded_context_configuration of this BTUpdateInContextParams.  # noqa: E501
        :type: str
        """

        self._encoded_context_configuration = encoded_context_configuration

    @property
    def use_latest_microversion(self):
        """Gets the use_latest_microversion of this BTUpdateInContextParams.  # noqa: E501


        :return: The use_latest_microversion of this BTUpdateInContextParams.  # noqa: E501
        :rtype: bool
        """
        return self._use_latest_microversion

    @use_latest_microversion.setter
    def use_latest_microversion(self, use_latest_microversion):
        """Sets the use_latest_microversion of this BTUpdateInContextParams.


        :param use_latest_microversion: The use_latest_microversion of this BTUpdateInContextParams.  # noqa: E501
        :type: bool
        """

        self._use_latest_microversion = use_latest_microversion

    @property
    def context_id(self):
        """Gets the context_id of this BTUpdateInContextParams.  # noqa: E501


        :return: The context_id of this BTUpdateInContextParams.  # noqa: E501
        :rtype: str
        """
        return self._context_id

    @context_id.setter
    def context_id(self, context_id):
        """Sets the context_id of this BTUpdateInContextParams.


        :param context_id: The context_id of this BTUpdateInContextParams.  # noqa: E501
        :type: str
        """

        self._context_id = context_id

    @property
    def description(self):
        """Gets the description of this BTUpdateInContextParams.  # noqa: E501


        :return: The description of this BTUpdateInContextParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTUpdateInContextParams.


        :param description: The description of this BTUpdateInContextParams.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTUpdateInContextParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
